package org.jboss.repro.stateful.timeout;

import javax.annotation.PostConstruct;
import javax.annotation.PreDestroy;
import javax.ejb.*;
import java.rmi.RemoteException;
import java.util.concurrent.TimeUnit;

@Remote(StatefulTimeoutRemote.class)
@RemoteHome(StatefulTimeoutHome.class)
@Stateful
@StatefulTimeout(value = 10L, unit = TimeUnit.SECONDS)
@TransactionManagement(TransactionManagementType.CONTAINER)
@TransactionAttribute(TransactionAttributeType.SUPPORTS)
public class StatefulTimeoutEjb implements SessionBean {
  public void ejbCreate() {
    System.out.println("ejbCreate: " + this);
  }

  @Override
  public void setSessionContext(SessionContext ctx) throws EJBException, RemoteException {
    System.out.println("setSessionContext: " + this);
  }

  @Override
  public void ejbRemove() throws EJBException, RemoteException {
    System.out.println("ejbRemove: " + this);
  }

  @Override
  public void ejbActivate() throws EJBException, RemoteException {
    System.out.println("ejbActivate: " + this);
  }

  @Override
  public void ejbPassivate() throws EJBException, RemoteException {
    System.out.println("ejbPassivate: " + this);
  }

  @TransactionAttribute(TransactionAttributeType.REQUIRES_NEW)
  @PostConstruct
  public void create() {
    System.out.println("createStatefulTimeout: " + this);
  }

  @TransactionAttribute(TransactionAttributeType.REQUIRES_NEW)
  @PreDestroy
  public void removeStateful() {
    System.out.println("removeStateful: " + this);
  }

  public String ping() throws RemoteException {
    final String nodeName = System.getProperty("jboss.node.name", "N/A");
    System.out.println("Pinged: " + nodeName);
    return nodeName;
  }
}
