package org.jboss.repro.stateful.timeout;

import javax.annotation.PostConstruct;
import javax.ejb.*;
import java.rmi.RemoteException;

@Remote(StatefulTimeoutManagerRemote.class)
@RemoteHome(StatefulTimeoutManagerHome.class)
@Stateless
@TransactionManagement(TransactionManagementType.CONTAINER)
@TransactionAttribute(TransactionAttributeType.SUPPORTS)
public class StatefulTimeoutManagerEjb implements SessionBean {
  @EJB
  private StatefulTimeoutHome statefulTimeoutHome;

  public void ejbCreate() {
    System.out.println("ejbCreate: " + this);
  }

  @Override
  public void setSessionContext(SessionContext ctx) throws EJBException, RemoteException {
    System.out.println("setSessionContext: " + this);
  }

  @Override
  public void ejbRemove() throws EJBException, RemoteException {
    System.out.println("ejbRemove: " + this);
  }

  @Override
  public void ejbActivate() throws EJBException, RemoteException {
    System.out.println("ejbActivate: " + this);
  }

  @Override
  public void ejbPassivate() throws EJBException, RemoteException {
    System.out.println("ejbPassivate: " + this);
  }

  @PostConstruct
  public void created() {
    System.out.println("created: " + this);
  }

  public void leak() throws RemoteException {
    System.out.println("leak: " + this);

    final StatefulTimeoutRemote bean = createStatefulTimeout();
    bean.ping();
  }

  public void noLeak() {
    try {
      System.out.println("noLeak: " + this);

      final StatefulTimeoutRemote bean = createStatefulTimeout();
      bean.ping();
      bean.removeStateful();
    } catch (RemoteException e) {
      throw new IllegalStateException("Unable to remove bean", e);
    }
  }

  public StatefulTimeoutRemote createStatefulTimeout() throws RemoteException {
    System.out.println("createStatefulTimeout: " + this);

    try {
      return statefulTimeoutHome.create();
    } catch (CreateException | RemoteException e) {
      throw new IllegalStateException(e);
    }
  }
}
